@@ -1,5 +1,5 @@
 /*
- * GNOME eime/date display module.
+ * GNOME time/date display module.
  * (C) 1997 The Free Software Foundation
  *
  * Authors: Miguel de Icaza
@@ -20,16 +20,27 @@
 #include <time.h>
 
 #include <panel-applet.h>
+#include <panel-applet-gconf.h>
 
 #include <gtk/gtk.h>
 #include <libbonobo.h>
 #include <libgnomeui/libgnomeui.h>
 #include <libgnome/libgnome.h>
+#include <gconf/gconf-client.h>
 
 #include "clock.h"
 
 #define INTERNETSECOND (864/4)
 
+static const char* KEY_HOUR_FORMAT	= "hour_format";
+static const char* KEY_SHOW_DATE 	= "show_date";
+static const char* KEY_SHOW_TOOLTIP	= "show_tooltip";
+static const char* KEY_GMT_TIME		= "gmt_time";
+static const char* KEY_UNIX_TIME	= "unix_time";
+static const char* KEY_INTERNET_TIME	= "internet_time";
+
+extern GtkTooltips *panel_tooltips;
+
 typedef struct _ClockData ClockData;
 
 typedef void (*ClockUpdateFunc) (ClockData *, time_t);
@@ -51,12 +62,6 @@ struct _ClockData {
 	int size;
 
 	GtkWidget *props;
-	int prop_hourformat;
-        gboolean prop_showdate;
-	gboolean prop_unixtime;
-	gboolean prop_internettime;
-	gboolean prop_gmt_time;
-	gboolean prop_showtooltip;
 };
 
 typedef struct {
@@ -74,13 +79,6 @@ static void display_help_dialog       (BonoboUIComponent *uic,
 static void display_about_dialog      (BonoboUIComponent *uic,
 				       ClockData         *cd,
 				       const gchar       *verbname);
-static void phelp_cb	     (GtkWidget *w, gint tab, gpointer data);
-
-static void
-free_data (gpointer data)
-{
-	g_free(data);
-}
 
 static int
 clock_timeout_callback (gpointer data)
@@ -121,29 +119,6 @@ clock_timeout_callback (gpointer data)
 	return TRUE;
 }
 
-#ifdef FIXME
-static gboolean
-applet_save_session(GtkWidget * w,
-		    const char *privcfgpath,
-		    const char *globcfgpath,
-		    gpointer data)
-{
-	ClockData *cd = data;
-	gnome_config_push_prefix(privcfgpath);
-	gnome_config_set_int("clock/hourformat", cd->hourformat);
-	gnome_config_set_int("clock/showdate", cd->showdate);
-	gnome_config_set_int("clock/unixtime", cd->unixtime);
-	gnome_config_set_int("clock/internettime", cd->internettime);
-	gnome_config_set_int("clock/showtooltip", cd->showtooltip);
-	gnome_config_set_int("clock/gmt_time", cd->gmt_time);
-	gnome_config_pop_prefix();
-	gnome_config_sync();
-	gnome_config_drop_all();
-
-	return FALSE;
-}
-#endif
-
 static float
 get_itime (time_t current_time)
 {
@@ -233,14 +208,15 @@ computer_clock_update_func (ClockData * cd,
 		g_string_append (gs, date);
 	}
 
-#ifdef FIXME
 	/* Set the applets tooltip */
 	if (cd->showtooltip && !cd->unixtime && !cd->internettime) {
-		if (strftime (tooltip, sizeof (tooltip), _("%A, %B %d"), tm) <= 0)
-			strcpy (tooltip, "???");
-		applet_widget_set_tooltip (APPLET_WIDGET (cd->applet), tooltip);
+		if (strftime (date, sizeof (date), _("%A, %B %d"), tm) <= 0)
+			strcpy (date, "???");
+		utf8 = g_locale_to_utf8 (date, -1, NULL, NULL, NULL);
+  		gtk_tooltips_set_tip (panel_tooltips, GTK_WIDGET (cd->applet),
+				      utf8, NULL);
+		g_free (utf8);
 	}
-#endif
 	
 	/*if we are vertical, just make it char per line */
 	if ((cd->orient == PANEL_APPLET_ORIENT_LEFT ||
@@ -265,6 +241,45 @@ computer_clock_update_func (ClockData * cd,
 	g_free (utf8);
 }
 
+static void
+refresh_clock (ClockData *cd)
+{
+	time_t current_time;
+	
+	time (&current_time);
+	(*cd->update_func) (cd, current_time);
+}
+
+static void
+refresh_clock_timeout(ClockData *cd)
+{
+	time_t current_time;
+	struct tm *tm;
+	
+	if (cd->timeout)
+		g_source_remove (cd->timeout);
+
+	time (&current_time);
+	(*cd->update_func) (cd, current_time);
+	
+	/* Install timeout handler */
+	if (cd->gmt_time)
+		tm = gmtime (&current_time);
+	else
+		tm = localtime (&current_time);
+
+	if(cd->unixtime)
+		cd->timeouttime = 1000;
+        else if (cd->internettime)
+                cd->timeouttime = INTERNETSECOND;
+	else
+		cd->timeouttime = 36000-(tm->tm_sec*600);
+	
+	cd->timeout = g_timeout_add (cd->timeouttime,
+				     clock_timeout_callback,
+				     cd);
+}
+
 static void
 create_computer_clock_widget (GtkWidget ** clock, ClockUpdateFunc * update_func)
 {
@@ -293,7 +308,7 @@ create_computer_clock_widget (GtkWidget ** clock, ClockUpdateFunc * update_func)
 	gtk_box_pack_start_defaults (GTK_BOX (vbox), cc->time);
 	gtk_widget_show (cc->time);
 
-	g_object_set_data_full (G_OBJECT (frame), "cc", cc, free_data);
+	g_object_set_data_full (G_OBJECT (frame), "cc", cc, g_free);
 
 	*clock = frame;
 	*update_func = computer_clock_update_func;
@@ -321,8 +336,6 @@ static void
 create_clock_widget (ClockData *cd)
 {
 	GtkWidget *clock;
-	struct tm *tm;
-	time_t current_time;
 
 	/*FIXME: different clock types here */
 	create_computer_clock_widget (&clock, &cd->update_func);
@@ -334,30 +347,12 @@ create_clock_widget (ClockData *cd)
 	cd->orient = panel_applet_get_orient (PANEL_APPLET (cd->applet));
 	cd->size = panel_applet_get_size (PANEL_APPLET (cd->applet));
 
-	gtk_signal_connect (GTK_OBJECT(clock), "destroy",
-			    (GtkSignalFunc) destroy_clock,
-			    cd);
+	g_signal_connect (G_OBJECT(clock), "destroy",
+			  G_CALLBACK (destroy_clock),
+			  cd);
 	
-	/* Call the clock's update function so that it paints its first state */
-	time (&current_time);
-	(*cd->update_func) (cd, current_time);
-
-	/* Install timeout handler */
-	if (cd->gmt_time)
-		tm = gmtime (&current_time);
-	else
-		tm = localtime (&current_time);
-    
-	if (cd->unixtime)
-		cd->timeouttime = 1000;
-        else if (cd->internettime)
-                cd->timeouttime = INTERNETSECOND;
-	else
-		cd->timeouttime = 36000 - (tm->tm_sec*600);
-	
-	cd->timeout = g_timeout_add (cd->timeouttime,
-				     clock_timeout_callback,
-				     cd);
+	/* Refresh the clock so that it paints its first state */
+	refresh_clock_timeout(cd);
 }
 
 /* this is when the panel orientation changes */
@@ -426,6 +421,7 @@ copy_time (BonoboUIComponent *uic,
 	time_t current_time = time (NULL);
 	struct tm *tm;
 	char string[256];
+	char *utf8;
 
 	if (cd->gmt_time)
 		tm = gmtime (&current_time);
@@ -450,8 +446,10 @@ copy_time (BonoboUIComponent *uic,
 			strcpy (string, "???");
 	}
 
+	utf8 = g_locale_to_utf8 (string, -1, NULL, NULL, NULL);
 	gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD),
-				string, -1);
+				utf8, -1);
+	g_free (utf8);
 }
 
 static void
@@ -462,6 +460,7 @@ copy_date (BonoboUIComponent *uic,
 	time_t current_time = time (NULL);
 	struct tm *tm;
 	char string[256];
+	char *utf8;
 
 	if (cd->gmt_time)
 		tm = gmtime (&current_time);
@@ -471,33 +470,13 @@ copy_date (BonoboUIComponent *uic,
 	if (strftime (string, sizeof (string), _("%A, %B %d %Y"), tm) <= 0)
 		strcpy (string, "???");
 	
+	utf8 = g_locale_to_utf8 (string, -1, NULL, NULL, NULL);
 	gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD),
-				string, -1);
+				utf8, -1);
+	g_free (utf8);
 }
 
-
 /* current timestamp */
-static void
-copy_timestamp (BonoboUIComponent *uic,
-		ClockData         *cd,
-		const gchar       *verbname)
-{
-	time_t current_time = time (NULL);
-	struct tm *tm;
-	char string[256];
-
-	tm = localtime (&current_time);
-
-	if (strftime (string, sizeof (string),
-		     /* RFC822 conformant date, likely not different for other
-		      * locales I don't think */
-		     _("%a, %d  %b  %Y %H:%M:%S %z"), tm) <= 0)
-		strcpy (string, "???");
-	
-	gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD),
-				string, -1);
-}
-
 static const BonoboUIVerb clock_menu_verbs [] = {
 	BONOBO_UI_UNSAFE_VERB ("ClockProperties", display_properties_dialog),
 	BONOBO_UI_UNSAFE_VERB ("ClockHelp",       display_help_dialog),
@@ -507,65 +486,227 @@ static const BonoboUIVerb clock_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
+static void
+hour_format_changed (GConfClient  *client,
+		     guint         cnxn_id,
+		     GConfEntry   *entry,
+		     ClockData *clock)
+{
+	int value;
+	
+	if (!entry->value || entry->value->type != GCONF_VALUE_INT)
+		return;
+
+	value = gconf_value_get_int (entry->value);
+	
+	if (value == 12 || value == 24)
+		clock->hourformat = value;
+	else
+		clock->hourformat = 12;
+
+	refresh_clock (clock);
+}
+
+static void
+show_date_changed (GConfClient  *client,
+		   guint         cnxn_id,
+		   GConfEntry   *entry,
+		   ClockData *clock)
+{
+	gboolean value;
+	
+	if (!entry->value || entry->value->type != GCONF_VALUE_BOOL)
+		return;
+
+	value = gconf_value_get_bool (entry->value);
+	
+	clock->showdate = (value != 0);
+	refresh_clock (clock);
+}
+
+static void
+internet_time_changed (GConfClient  *client,
+		       guint         cnxn_id,
+		       GConfEntry   *entry,
+		       ClockData *clock)
+{
+	gboolean value;
+	
+	if (!entry->value || entry->value->type != GCONF_VALUE_BOOL)
+		return;
+
+	value = gconf_value_get_bool (entry->value);
+	
+	clock->internettime = (value != 0);
+	refresh_clock_timeout (clock);
+}
+
+static void
+unix_time_changed (GConfClient  *client,
+		  guint         cnxn_id,
+		  GConfEntry   *entry,
+		  ClockData *clock)
+{
+	gboolean value;
+	
+	if (!entry->value || entry->value->type != GCONF_VALUE_BOOL)
+		return;
+
+	value = gconf_value_get_bool (entry->value);
+	
+	clock->unixtime = (value != 0);
+	refresh_clock_timeout (clock);
+}
+
+static void
+gmt_time_changed (GConfClient  *client,
+		  guint         cnxn_id,
+		  GConfEntry   *entry,
+		  ClockData *clock)
+{
+	gboolean value;
+	
+	if (!entry->value || entry->value->type != GCONF_VALUE_BOOL)
+		return;
+
+	value = gconf_value_get_bool (entry->value);
+	
+	clock->gmt_time = (value != 0);
+	refresh_clock_timeout (clock);
+}
+
+static void
+show_tooltip_changed (GConfClient  *client,
+		      guint         cnxn_id,
+		      GConfEntry   *entry,
+		      ClockData *clock)
+{
+	gboolean value;
+	
+	if (!entry->value || entry->value->type != GCONF_VALUE_BOOL)
+		return;
+
+	value = gconf_value_get_bool (entry->value);
+	
+	clock->showtooltip = (value != 0);
+	refresh_clock (clock);
+}
+
+static void
+setup_gconf (ClockData *clock)
+{
+	GConfClient *client;
+	char *key;
+
+	client = gconf_client_get_default ();
+
+	key = panel_applet_gconf_get_full_key (PANEL_APPLET (clock->applet),
+					       KEY_HOUR_FORMAT);
+	gconf_client_notify_add(client, key,
+				(GConfClientNotifyFunc)hour_format_changed,
+				clock,
+				NULL, NULL);
+	g_free (key);
+
+	key = panel_applet_gconf_get_full_key (PANEL_APPLET (clock->applet),
+					       KEY_SHOW_DATE);
+	gconf_client_notify_add(client, key,
+				(GConfClientNotifyFunc)show_date_changed,
+				clock,
+				NULL, NULL);
+	g_free (key);
+
+	key = panel_applet_gconf_get_full_key (PANEL_APPLET (clock->applet),
+					       KEY_SHOW_TOOLTIP);
+	gconf_client_notify_add(client, key,
+				(GConfClientNotifyFunc)show_tooltip_changed,
+				clock,
+				NULL, NULL);
+	g_free (key);
+
+	key = panel_applet_gconf_get_full_key (PANEL_APPLET (clock->applet),
+					       KEY_GMT_TIME);
+	gconf_client_notify_add(client, key,
+				(GConfClientNotifyFunc)gmt_time_changed,
+				clock,
+				NULL, NULL);
+	g_free (key);
+
+	key = panel_applet_gconf_get_full_key (PANEL_APPLET (clock->applet),
+					       KEY_UNIX_TIME);
+	gconf_client_notify_add(client, key,
+				(GConfClientNotifyFunc)unix_time_changed,
+				clock,
+				NULL, NULL);
+	g_free (key);
+
+	key = panel_applet_gconf_get_full_key (PANEL_APPLET (clock->applet),
+					       KEY_INTERNET_TIME);
+	gconf_client_notify_add(client, key,
+				(GConfClientNotifyFunc)internet_time_changed,
+				clock,
+				NULL, NULL);
+	g_free (key);
+}
+
 gboolean
 fill_clock_applet(PanelApplet *applet)
 {
 	ClockData *cd;
+	GError *error;
+	
+	panel_applet_add_preferences (applet, "/schemas/apps/clock-applet/prefs", NULL);
 	
 	cd = g_new0 (ClockData, 1);
 
 	cd->applet = GTK_WIDGET (applet);
 
-	/* FIXME: The config stuff needs to be completely redone... */
-	
-	//	gnome_config_push_prefix(APPLET_WIDGET(applet)->privcfgpath);
+	setup_gconf (cd);
 
-	/* A kluge to allow translation of default hour format to 12 or
-	 * 24 hour format */
-	{
-		/* Do NOT translate the clock/hourformat part.  What you
-		 * should change is the 12.  If your country code should use
+	error = NULL;
+	cd->hourformat = panel_applet_gconf_get_bool (applet, KEY_HOUR_FORMAT, &error);
+	if (error) {
+		/* Do NOT translate the clock/hourformat= part.  What you
+		 * should change is the number 12.  If your country code should use
 		 * 12 hour format by default, leave it at 12, otherwise use 24
 		 * for 24 hour format.  Those are the only two supported */
 		char *transl = _("clock/hourformat=12");
+		const int len = strlen ("clock/hourformat=");
 		/* sanity */
-		if (strncmp (transl, "clock/hourformat=",
-			     strlen ("clock/hourformat=") != 0)) {
+		if (strncmp (transl, "clock/hourformat=", len)) {
 			g_warning("Clock applet string clock/hourformat=12 "
 				  "was not translated correctly in this locale.");
-			transl = "clock/hourformat=12";
-		}
-		
-		cd->hourformat = gnome_config_get_int (transl);
-
-		/* support the old syntax */
-		if (cd->hourformat == 0)
 			cd->hourformat = 12;
-		else if (cd->hourformat == 1)
-			cd->hourformat = 24;
+		} else {
+			cd->hourformat = atoi (transl + len);
+			if (cd->hourformat != 12 && cd->hourformat != 24)
+				cd->hourformat = 12;
+		}
 
-		/* make sure it's a sane value, we use 24 otherwise */
-		if (cd->hourformat != 12 && cd->hourformat != 24)
-			cd->hourformat = 24;
+		g_error_free (error);
 	}
-	/* if on a small screen don't show data by default */
-	if (gdk_screen_width () <= 800)
-		cd->showdate = gnome_config_get_int ("clock/showdate=0");
-	else
-		cd->showdate = gnome_config_get_int ("clock/showdate=1");
 
-	cd->unixtime = gnome_config_get_int ("clock/unixtime=0");
-	cd->internettime = gnome_config_get_int ("clock/internettime=0");
-	
-	/* if on a small screen show tooltip with date by default */
-	if (gdk_screen_width() <= 800)
-		cd->showtooltip = gnome_config_get_int ("clock/showtooltip=1");
-	else
-		cd->showtooltip = gnome_config_get_int ("clock/showtooltip=0");
-	
-	cd->gmt_time = gnome_config_get_int ("clock/gmt_time=0");
-	
-	//gnome_config_pop_prefix();
+	error = NULL;
+	cd->showdate = panel_applet_gconf_get_bool (applet, KEY_SHOW_DATE, &error);
+	if (error) {
+		g_error_free (error);
+		/* if on a small screen don't show data by default */
+		if (gdk_screen_width () <= 800)
+			cd->showdate = FALSE;
+		else
+			cd->showdate = TRUE;
+	}
+
+	error = NULL;
+	cd->showtooltip = panel_applet_gconf_get_bool (applet, KEY_SHOW_TOOLTIP, &error);
+	if (error) {
+		g_error_free (error);
+		cd->showtooltip = TRUE; /* Default value*/
+	}
+
+	cd->gmt_time = panel_applet_gconf_get_bool (applet, KEY_GMT_TIME, NULL);
+	cd->unixtime = panel_applet_gconf_get_bool (applet, KEY_UNIX_TIME, NULL);
+	cd->internettime = panel_applet_gconf_get_bool (applet, KEY_INTERNET_TIME, NULL);
 
 	create_clock_widget (cd);
 
@@ -594,14 +735,6 @@ fill_clock_applet(PanelApplet *applet)
 			  G_CALLBACK (applet_change_background),
 			  cd);
 
-	
-#ifdef FIXME
-	g_signal_connect (G_OBJECT (cd->applet),
-			  "save_session",
-			  G_CALLBACK (applet_save_session),
-			  cd);
-#endif
-
 	panel_applet_setup_menu_from_file (PANEL_APPLET (cd->applet),
 					   NULL,
 					   "GNOME_ClockApplet.xml",
@@ -612,82 +745,6 @@ fill_clock_applet(PanelApplet *applet)
 	return TRUE;
 }
 
-static void
-apply_properties (GtkWidget * widget, gint button_num, gpointer data)
-{
-	ClockData *cd = data;
-	time_t current_time;
-	struct tm *tm;
-
-	cd->hourformat = cd->prop_hourformat;
-	cd->showdate = cd->prop_showdate;
-	cd->unixtime = cd->prop_unixtime;
-   	cd->internettime = cd->prop_internettime;
-	cd->gmt_time = cd->prop_gmt_time;
-	cd->showtooltip = cd->prop_showtooltip;
-
-	/* Call the clock's update function so that it paints its first state */
-	time (&current_time);
-	(*cd->update_func) (cd, current_time);
-	
-	g_source_remove (cd->timeout);
-
-	/* Install timeout handler */
-	if (cd->gmt_time)
-		tm = gmtime (&current_time);
-	else
-		tm = localtime (&current_time);
-
-	if(cd->unixtime)
-		cd->timeouttime = 1000;
-        else if (cd->internettime)
-                cd->timeouttime = INTERNETSECOND;
-	else
-		cd->timeouttime = 36000-(tm->tm_sec*600);
-	
-	cd->timeout = g_timeout_add (cd->timeouttime,
-				     clock_timeout_callback,
-				     cd);
-#ifdef FIXME
-	if(!cd->showtooltip || cd->unixtime || cd->internettime)
-  		applet_widget_set_tooltip(APPLET_WIDGET(cd->applet), "");
-#endif
-				      
-	/* gtk_widget_queue_resize (cd->clockw);*/
-}
-
-static void
-close_properties (GtkWidget *w,
-		  gpointer   data)
-{
-	ClockData *cd = data;
-
-	cd->props = NULL;
-}
-
-static void
-set_hour_format_cb (GtkWidget *w,
-		    gpointer   data)
-{
-	g_return_if_fail (w != NULL);
-	
-	if (GTK_TOGGLE_BUTTON (w)->active) {
-		ClockData *cd = gtk_object_get_user_data (GTK_OBJECT (w));
-		cd->prop_hourformat = GPOINTER_TO_INT (data);
-		gnome_property_box_changed (GNOME_PROPERTY_BOX (cd->props));
-	}
-}
-
-static void
-set_show_date_cb (GtkWidget *w,
-		  gpointer   data)
-{
-	ClockData *cd = data;
-
-	cd->prop_showdate = GTK_TOGGLE_BUTTON (w)->active;
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (cd->props));
-}
-
 static void
 set_datasensitive_cb (GtkWidget *w,
 		      GtkWidget *wid)
@@ -696,43 +753,86 @@ set_datasensitive_cb (GtkWidget *w,
 }
 
 static void
-set_internettime_cb (GtkWidget *w,
-		     gpointer   data)
+set_hour_format_cb (GtkWidget *w,
+		    gpointer data)
 {
-	ClockData *cd = data;
+	if (GTK_TOGGLE_BUTTON (w)->active) {
+		ClockData *clock = g_object_get_data (G_OBJECT (w), "user_data");
+		panel_applet_gconf_set_int (PANEL_APPLET (clock->applet),
+					    KEY_HOUR_FORMAT,
+					    GPOINTER_TO_INT (data),
+					    NULL);
+	}
+}
 
-	cd->prop_internettime = GTK_TOGGLE_BUTTON (w)->active;
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (cd->props));
+static void
+set_show_date_cb (GtkWidget *w,
+		  ClockData *clock)
+{
+	panel_applet_gconf_set_bool (PANEL_APPLET (clock->applet),
+				     KEY_SHOW_DATE,
+				     GTK_TOGGLE_BUTTON (w)->active,
+				     NULL);
+}
+
+static void
+set_internettime_cb (GtkWidget *w,
+		     ClockData *clock)
+{
+	panel_applet_gconf_set_bool (PANEL_APPLET (clock->applet),
+				     KEY_INTERNET_TIME,
+				     GTK_TOGGLE_BUTTON (w)->active,
+				     NULL);
 }
 
 static void
 set_unixtime_cb (GtkWidget *w,
-		 gpointer   data)
+		 ClockData *clock)
 {
-	ClockData *cd = data;
-
-	cd->prop_unixtime = GTK_TOGGLE_BUTTON (w)->active;
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (cd->props));
+	panel_applet_gconf_set_bool (PANEL_APPLET (clock->applet),
+				     KEY_UNIX_TIME,
+				     GTK_TOGGLE_BUTTON (w)->active,
+				     NULL);
 }
 
 static void
 set_gmt_time_cb (GtkWidget *w,
-		 gpointer   data)
+		 ClockData *clock)
 {
-	ClockData *cd = data;
-
-	cd->prop_gmt_time = GTK_TOGGLE_BUTTON (w)->active;
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (cd->props));
+	panel_applet_gconf_set_bool (PANEL_APPLET (clock->applet),
+				     KEY_GMT_TIME,
+				     GTK_TOGGLE_BUTTON (w)->active,
+				     NULL);
 }
 
 static void
 set_show_tooltip_cb (GtkWidget * w,
-		     gpointer data)
+		     ClockData *clock)
 {
-	ClockData *cd = data;
+	panel_applet_gconf_set_bool (PANEL_APPLET (clock->applet),
+				     KEY_SHOW_TOOLTIP,
+				     GTK_TOGGLE_BUTTON (w)->active,
+				     NULL);
+}
 
-	cd->prop_showtooltip = GTK_TOGGLE_BUTTON (w)->active;
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (cd->props));
+static void
+properties_response_cb (GtkWidget *widget, gint id, gpointer data)
+{
+	
+	if (id == GTK_RESPONSE_HELP) {
+		GError *error = NULL;
+
+		gnome_help_display_desktop (NULL, "clock", "clock",
+				            "CLOCK-SETTINGS", &error);
+		if (error) {
+			g_warning ("help error: %s\n", error->message);
+			g_error_free (error);
+		}
+	} else {
+		gtk_widget_destroy (widget);
+	}
+	
+	return;
 }
 
 static void 
@@ -755,15 +855,16 @@ display_properties_dialog (BonoboUIComponent *uic,
 	gchar *file;
 
 	if (cd->props != NULL) {
-		gtk_widget_show (cd->props);
 		gtk_window_present (GTK_WINDOW (cd->props));
 		return;
 	}
 
-	cd->props = gnome_property_box_new();
-	gtk_window_set_title (GTK_WINDOW (cd->props),
-			      _("Clock properties"));
-	gtk_window_set_wmclass (GTK_WINDOW (cd->props), "clock", "Clock");
+	cd->props = gtk_dialog_new_with_buttons (_("Clock Properties"), NULL, 0,
+						 GTK_STOCK_HELP,
+						 GTK_RESPONSE_HELP,
+						 GTK_STOCK_CLOSE,
+						 GTK_RESPONSE_CLOSE,
+						 NULL);
 
 	pixbuf = NULL;
 	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-clock.png", TRUE, NULL);
@@ -778,7 +879,7 @@ display_properties_dialog (BonoboUIComponent *uic,
 	}
 
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD);
-
+	
 	hour_frame = gtk_frame_new (_("Time Format"));
 	gtk_container_set_border_width (GTK_CONTAINER (hour_frame), GNOME_PAD);
 	gtk_box_pack_start (GTK_BOX (hbox), hour_frame, FALSE, FALSE, 0);
@@ -795,16 +896,16 @@ display_properties_dialog (BonoboUIComponent *uic,
 	gtk_table_attach (GTK_TABLE (table), twelvehour, 0, 1, 0, 1,
 			  GTK_FILL, GTK_FILL | GTK_EXPAND,
 			  0, 0);
-	gtk_object_set_user_data (GTK_OBJECT (twelvehour), (gpointer) cd);
+	g_object_set_data (G_OBJECT (twelvehour), "user_data", cd);
 	gtk_widget_show (twelvehour);
 
-	twentyfourhour = gtk_radio_button_new_with_label (gtk_radio_button_group (GTK_RADIO_BUTTON (twelvehour)),
+	twentyfourhour = gtk_radio_button_new_with_label (gtk_radio_button_get_group (GTK_RADIO_BUTTON (twelvehour)),
 							  _("24 hour"));
 
 	gtk_table_attach (GTK_TABLE (table), twentyfourhour, 0, 1, 1, 2,
 			  GTK_FILL, GTK_FILL | GTK_EXPAND,
 			  0, 0);
-	gtk_object_set_user_data (GTK_OBJECT (twentyfourhour), (gpointer) cd);
+	g_object_set_data (G_OBJECT (twentyfourhour), "user_data", cd);
 	gtk_widget_show (twentyfourhour);
 
 	switch (cd->hourformat) {
@@ -819,16 +920,12 @@ display_properties_dialog (BonoboUIComponent *uic,
 		break;
 	}
 
-	cd->prop_hourformat = cd->hourformat;
-
-	gtk_signal_connect (GTK_OBJECT (twelvehour),
-			    "toggled",
-			    (GtkSignalFunc) set_hour_format_cb,
-			    (gpointer) 12);
-	gtk_signal_connect (GTK_OBJECT (twentyfourhour),
-			    "toggled",
-			    (GtkSignalFunc) set_hour_format_cb,
-			    (gpointer) 24);
+	g_signal_connect (G_OBJECT (twelvehour), "toggled",
+			  G_CALLBACK (set_hour_format_cb),
+			  GINT_TO_POINTER (12));
+	g_signal_connect (G_OBJECT (twentyfourhour), "toggled",
+			  G_CALLBACK (set_hour_format_cb),
+			  GINT_TO_POINTER (24));
 	
 	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start_defaults (GTK_BOX (hbox), vbox);
@@ -841,12 +938,9 @@ display_properties_dialog (BonoboUIComponent *uic,
 	if (cd->showdate)
 	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (showdate),
 					TRUE);
-	cd->prop_showdate = cd->showdate;
-	
-	gtk_signal_connect (GTK_OBJECT (showdate),
-			    "toggled",
-			    (GtkSignalFunc) set_show_date_cb,
-			    cd);	   
+	g_signal_connect (G_OBJECT (showdate), "toggled",
+			  G_CALLBACK (set_show_date_cb),
+			  cd);	   
 
 	showtooltip = gtk_check_button_new_with_label (_("Show date in tooltip"));
 	gtk_box_pack_start_defaults (GTK_BOX (vbox), showtooltip);
@@ -855,12 +949,9 @@ display_properties_dialog (BonoboUIComponent *uic,
 	if (cd->showtooltip)
 	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (showtooltip),
 					TRUE);
-	cd->prop_showtooltip = cd->showtooltip;
-	
-	gtk_signal_connect (GTK_OBJECT (showtooltip),
-			    "toggled",
-			    (GtkSignalFunc) set_show_tooltip_cb,
-			    cd);	
+	g_signal_connect (G_OBJECT (showtooltip), "toggled",
+			  G_CALLBACK (set_show_tooltip_cb),
+			  cd);	
 
 	use_gmt_time = gtk_check_button_new_with_label (_("Use GMT"));
 	gtk_box_pack_start_defaults (GTK_BOX (vbox), use_gmt_time);
@@ -869,12 +960,9 @@ display_properties_dialog (BonoboUIComponent *uic,
 	if (cd->gmt_time)
 	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (use_gmt_time),
 					TRUE);
-	cd->prop_gmt_time = cd->gmt_time;
-	
-	gtk_signal_connect (GTK_OBJECT (use_gmt_time),
-			    "toggled",
-			    (GtkSignalFunc) set_gmt_time_cb,
-			    cd);	
+	g_signal_connect (G_OBJECT (use_gmt_time), "toggled",
+			  G_CALLBACK (set_gmt_time_cb),
+			  cd);	
 
 	unixtime = gtk_check_button_new_with_label (_("Unix time"));
 	gtk_box_pack_start_defaults (GTK_BOX (vbox), unixtime);
@@ -884,68 +972,57 @@ display_properties_dialog (BonoboUIComponent *uic,
 	gtk_box_pack_start_defaults (GTK_BOX (vbox), internettime);
 	gtk_widget_show (internettime);
    
-        gtk_signal_connect (GTK_OBJECT (unixtime), "toggled",
-			    (GtkSignalFunc) set_datasensitive_cb,
-			    hour_frame);
-	gtk_signal_connect (GTK_OBJECT (unixtime), "toggled",
-			    (GtkSignalFunc) set_datasensitive_cb,
-			    showdate);
-	gtk_signal_connect (GTK_OBJECT (unixtime), "toggled",
-			    (GtkSignalFunc) set_datasensitive_cb,
-			    showtooltip);
-	gtk_signal_connect (GTK_OBJECT (unixtime), "toggled",
-			    (GtkSignalFunc) set_datasensitive_cb,
-			    use_gmt_time);
-	gtk_signal_connect (GTK_OBJECT (unixtime), "toggled",
-			    (GtkSignalFunc) set_datasensitive_cb,
-			    internettime);
+        g_signal_connect (G_OBJECT (unixtime), "toggled",
+			  G_CALLBACK (set_datasensitive_cb),
+			  hour_frame);
+	g_signal_connect (G_OBJECT (unixtime), "toggled",
+			  G_CALLBACK (set_datasensitive_cb),
+			  showdate);
+	g_signal_connect (G_OBJECT (unixtime), "toggled",
+			  G_CALLBACK (set_datasensitive_cb),
+			  use_gmt_time);
+	g_signal_connect (G_OBJECT (unixtime), "toggled",
+			  G_CALLBACK (set_datasensitive_cb),
+			  internettime);
 			   
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (unixtime),
 				      cd->unixtime);
-	cd->prop_unixtime = cd->unixtime;
-
 
 /* internet time */
-	gtk_signal_connect (GTK_OBJECT (internettime), "toggled",
-			    (GtkSignalFunc) set_datasensitive_cb,
-			    hour_frame);
-	gtk_signal_connect (GTK_OBJECT (internettime), "toggled",
-			   (GtkSignalFunc) set_datasensitive_cb,
-			    showdate);
-	gtk_signal_connect (GTK_OBJECT (internettime), "toggled",
-			    (GtkSignalFunc) set_datasensitive_cb,
-			    showtooltip);
-	gtk_signal_connect (GTK_OBJECT (internettime), "toggled",
-			    (GtkSignalFunc) set_datasensitive_cb,
-			    use_gmt_time);   
-	gtk_signal_connect (GTK_OBJECT (internettime), "toggled",
-			    (GtkSignalFunc) set_datasensitive_cb,
-			    unixtime);   
+	g_signal_connect (G_OBJECT (internettime), "toggled",
+			  G_CALLBACK (set_datasensitive_cb),
+			  hour_frame);
+	g_signal_connect (G_OBJECT (internettime), "toggled",
+			  G_CALLBACK (set_datasensitive_cb),
+			  showdate);
+	g_signal_connect (G_OBJECT (internettime), "toggled",
+			  G_CALLBACK (set_datasensitive_cb),
+			  use_gmt_time);   
+	g_signal_connect (G_OBJECT (internettime), "toggled",
+			  G_CALLBACK (set_datasensitive_cb),
+			  unixtime);   
    
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (internettime),
 				      cd->internettime);
-	cd->prop_internettime = cd->internettime;
    
-	gtk_signal_connect (GTK_OBJECT (unixtime), "toggled",
-			    (GtkSignalFunc) set_unixtime_cb,
-			    cd);
-	gtk_signal_connect (GTK_OBJECT (internettime), "toggled",
-			    (GtkSignalFunc) set_internettime_cb,
+	g_signal_connect (G_OBJECT (unixtime), "toggled",
+			  G_CALLBACK (set_unixtime_cb),
 			    cd);
+	g_signal_connect (G_OBJECT (internettime), "toggled",
+			  G_CALLBACK (set_internettime_cb),
+			  cd);
 
 	gtk_widget_show (hour_frame);
 	gtk_widget_show (hbox);
 
-	gnome_property_box_append_page (GNOME_PROPERTY_BOX (cd->props), hbox,
-					gtk_label_new (_("Clock")));
-	gtk_signal_connect (GTK_OBJECT (cd->props), "apply",
-			    GTK_SIGNAL_FUNC (apply_properties), cd);
-	gtk_signal_connect (GTK_OBJECT (cd->props), "destroy",
-			    GTK_SIGNAL_FUNC (close_properties), cd);
-	gtk_signal_connect (GTK_OBJECT (cd->props), "help",
-			    GTK_SIGNAL_FUNC (phelp_cb),
-			    "index.html#CLOCK-PREFS");
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (cd->props)->vbox), hbox, FALSE, FALSE, 0);
+
 	
+	g_signal_connect (G_OBJECT (cd->props), "destroy",
+			  G_CALLBACK (gtk_widget_destroyed), &(cd->props));
+	g_signal_connect (G_OBJECT (cd->props), "response",
+			  G_CALLBACK (properties_response_cb), NULL);
+				
 	gtk_widget_show (cd->props);
 }
 
@@ -963,14 +1040,6 @@ display_help_dialog (BonoboUIComponent *uic,
 	}
 }
 
-static void
-phelp_cb (GtkWidget *w, gint tab, gpointer data)
-{
-#ifdef FIXME
-		help_cb (NULL, data);
-#endif
-}
-
 static void
 display_about_dialog (BonoboUIComponent *uic,
 		      ClockData         *cd,
@@ -992,7 +1061,6 @@ display_about_dialog (BonoboUIComponent *uic,
 
 	if (about != NULL)
 	{
-		gtk_widget_show (about);
 		gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
@@ -1025,3 +1093,4 @@ display_about_dialog (BonoboUIComponent *uic,
 	
 	gtk_widget_show (about);
 }
+
