@@ -9,6 +9,10 @@
 
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE 1
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
@@ -138,17 +142,6 @@ static const BonoboUIVerb pager_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-static const char pager_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"Pager Properties Item\" verb=\"PagerProperties\" _label=\"Properties ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"Pager Help Item\" verb=\"PagerHelp\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"Pager About Item\" verb=\"PagerAbout\" _label=\"About ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-	"</popup>\n";
-
-
 static void
 num_rows_changed (GConfClient *client,
 		  guint        cnxn_id,
@@ -354,7 +347,12 @@ fill_pager_applet(PanelApplet *applet)
 			  G_CALLBACK (applet_change_pixel_size),
 			  pager);
 	
-	panel_applet_setup_menu (PANEL_APPLET (pager->applet), pager_menu_xml, pager_menu_verbs, pager);
+	panel_applet_setup_menu_from_file (PANEL_APPLET (pager->applet),
+					   NULL,
+					   "GNOME_PagerApplet.xml",
+					   NULL,
+					   pager_menu_verbs,
+					   pager);
 
 	return TRUE;
 }
@@ -365,7 +363,13 @@ display_help_dialog (BonoboUIComponent *uic,
 		     PagerData         *pager,
 		     const gchar       *verbname)
 {
-	/* TODO: Implement this */
+	GError *error = NULL;
+
+	gnome_help_display_desktop (NULL, "pager", "pager", NULL, &error);
+	if (error) {
+		g_warning ("help error: %s\n", error->message);
+		g_error_free (error);
+	}
 }
 
 static void
@@ -398,9 +402,9 @@ display_about_dialog (BonoboUIComponent *uic,
 		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	}
 
-	about = gnome_about_new (_("Pager Applet"), "1.0",
+	about = gnome_about_new (_("Workspace Switcher"), "1.0",
 				 _("(c) 2001 Red Hat, Inc."),
-				 _("The pager applet shows you a small version of your workspaces that lets you manage the windows."),
+				 _("The Workspace Switcher shows you a small version of your workspaces that lets you manage the windows."),
 				 authors,
 				 NULL, /* documenters */
 				 NULL, /* translator_credits */
@@ -551,6 +555,14 @@ workspace_name_edited (GtkCellRendererText *cell_renderer_text,
 	g_slist_free (list);
 }
 
+static gboolean
+delete_event (GtkWidget *widget, gpointer data)
+{
+	gtk_widget_hide (widget);
+	return TRUE;
+}
+
+
 #define WID(s) glade_xml_get_widget (xml, s)
 
 static void
@@ -600,6 +612,9 @@ setup_dialog (GladeXML  *xml,
 
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (pager->num_rows_spin), pager->n_rows);
 
+	g_signal_connect (pager->properties_dialog, "delete_event",
+			  G_CALLBACK (delete_event),
+			  pager);
 	
 	g_signal_connect_swapped (WID ("done_button"), "clicked",
 				  (GCallback) gtk_widget_hide, pager->properties_dialog);
