@@ -95,8 +95,7 @@ void       panel_applet_frame_save_to_gconf     (PanelAppletFrame *frame,
 
 void       panel_applet_frame_load_from_gconf   (PanelWidget *panel_widget,
 						 gint         position,
-						 const char  *gconf_key,
-						 gboolean     use_default);
+						 const char  *gconf_key);
 
 G_END_DECLS
 
