@@ -1156,6 +1156,9 @@ panel_applet_factory_main_closure (const gchar *iid,
 
 	g_assert (g_type_is_a (applet_type, PANEL_TYPE_APPLET));
 
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	closure = bonobo_closure_store (closure, panel_applet_marshal_BOOLEAN__STRING);
 
 	data = panel_applet_callback_data_new (applet_type, closure);
@@ -1208,6 +1211,9 @@ panel_applet_shlib_factory_closure (const char         *iid,
 
 	g_assert (g_type_is_a (applet_type, PANEL_TYPE_APPLET));
 
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	closure = bonobo_closure_store (closure, panel_applet_marshal_BOOLEAN__STRING);
        
 	factory = bonobo_shlib_factory_new_closure (
